DevItem

Struct DevItem 

#[repr(C, packed(1))]
pub struct DevItem {
Show 14 fields pub devid: U64, pub total_bytes: U64, pub bytes_used: U64, pub io_align: U32, pub io_width: U32, pub sector_size: U32, pub dev_type: U64, pub generation: U64, pub start_offset: U64, pub dev_group: U32, pub seek_speed: u8, pub bandwith: u8, pub uuid: UuidBytes, pub fsid: UuidBytes,
}
Represents a complete block device.

Fields

devid: U64

The internal btrfs device ID.

This should match the devid found in the filesystem’s list of devices.

total_bytes: U64

The size of the device.

bytes_used: U64

The bytes in use by the filesystem on the device.

io_align: U32

The optimal I/O alignment for this device.

io_width: U32

The optimal I/O width for this device.

sector_size: U32

The minimum I/O size for this device.

dev_type: U64

The type and info for this device.

generation: U64

The expected generation for this device.

start_offset: U64

The starting byte of this partition on the device, to allow for stripe alignment.

dev_group: U32

Grouping information for allocation decisions.

seek_speed: u8

The seek speed of the device on a scale from 0 to 100, where 100 is the fastest.

bandwith: u8

The bandwidth of the device on a scale from 0 to 100, where 100 is the fastest.

uuid: UuidBytes

The generated UUID for this device.

fsid: UuidBytes

The UUID of the filesystem that owns this device.