InodeItem

Struct InodeItem 

#[repr(C, packed(1))]
pub struct InodeItem {
Show 17 fields pub generation: U64, pub transid: U64, pub size: U64, pub nbytes: U64, pub block_group: U64, pub nlink: U32, pub uid: U32, pub gid: U32, pub mode: U32, pub rdev: U64, pub flags: U64, pub sequence: U64, pub _unused: [u64; 4], pub atime: Time, pub ctime: Time, pub mtime: Time, pub otime: Time,
}
Contains traditional inode data and attributes.

Fields

generation: U64transid: U64size: U64

The size of a file, in bytes.

nbytes: U64

The size allocated to the file, in bytes.

This is equal to the sum of all of the extent data for the inode. This is 0 for directories.

block_group: U64

This contains the byte offset of a block group when structure is a free space inode.

This value is unused for normal inodes.

nlink: U32

Count of inode references for the inode.

When used outside of a file tree, this value is 1.

uid: U32

The user ID of the owner in Unix.

gid: U32

The group ID of the group owner in Unix.

mode: U32

The Unix protection mode.

rdev: U64

The device identifier (if a special file).

flags: U64

Flags for the inode. See InodeFlags for values.

sequence: U64

A sequence number used for compatibility with NFS.

This value is initialized to 0 and incremented each time mtime is updated.

_unused: [u64; 4]atime: Time

Timestamp of the last access to the inode.

ctime: Time

Timestamp of the last change to the inode’s properties.

mtime: Time

Timestamp of the last change to the inode’s contents.

otime: Time

Timestamp of the creation of the inode.