SuperBlock

Struct SuperBlock 

#[repr(C, packed(1))]
pub struct SuperBlock {
Show 35 fields pub csum: [u8; 32], pub fsid: [u8; 16], pub bytenr: U64, pub flags: U64, pub magic: U64, pub generation: U64, pub root: U64, pub chunk_root: U64, pub log_root: U64, pub log_root_transid: U64, pub total_bytes: U64, pub bytes_used: U64, pub root_dir_objectid: U64, pub num_devices: U64, pub sectorsize: U32, pub nodesize: U32, pub leafsize: U32, pub stripesize: U32, pub sys_chunk_array_size: U32, pub chunk_root_generation: U64, pub compat_flags: U64, pub compat_ro_flags: U64, pub incompat_flags: U64, pub csum_type: ChecksumType, pub root_level: u8, pub chunk_root_level: u8, pub log_root_level: u8, pub dev_item: DevItem, pub label: [u8; 256], pub cache_generation: U64, pub uuid_tree_generation: U64, pub _reserved: [U64; 30], pub sys_chunk_array: [u8; 2048], pub super_roots: [RootBackup; 4], pub _unused1: [u8; 565],
}
The layout of the superblock. A valid superblock must exist for most btrfs implementations to mount the filesystem.

The primary superblock is located at PRIMARY_SUPERBLOCK_ADDR.

There are additional copies of the superblock located at SUPERBLOCK_ADDRS, if those addresses are valid, respectively.

Resources

Fields

csum: [u8; 32]

Checksum of everything past this field.

fsid: [u8; 16]

Filesystem UUID.

bytenr: U64

The physical address of this block.

flags: U64

Flags

magic: U64

The magic must be equal to "_BHRfS_M" in ASCII.

generation: U64

The generation of the superblock. In SSD mode, not all superblocks may be updated, so the latest generation superblock should be used.

root: U64

The logical address of the root tree’s root.

chunk_root: U64

The logical address of the chunk tree’s root.

log_root: U64

The logical address of the log tree’s root.

log_root_transid: U64

FIXME: find out what this is!

total_bytes: U64

FIXME: document this!

bytes_used: U64root_dir_objectid: U64

The root directory’s object ID, which is typically 6.

num_devices: U64

The number of devices the current filesystem spans.

sectorsize: U32

The size of a sector.

nodesize: U32leafsize: U32

This is currently unused.

stripesize: U32sys_chunk_array_size: U32

The size of sys_chunk_array found in the superblock.

chunk_root_generation: U64compat_flags: U64compat_ro_flags: U64

Only implementations that support these flags can write to the filesystem.

incompat_flags: U64

Only implementations that support these flags can use the filesystem.

csum_type: ChecksumType

The checksum type.

This should correspond with a value from ChecksumType.

root_level: u8chunk_root_level: u8log_root_level: u8dev_item: DevItemlabel: [u8; 256]

The label represented as a null-terminated UTF-8 string. May not contain '/' or '\\'.

cache_generation: U64uuid_tree_generation: U64_reserved: [U64; 30]

Reserved for extensibility.

sys_chunk_array: [u8; 2048]super_roots: [RootBackup; 4]_unused1: [u8; 565]